<?php

/**
  * SquirrelMail Login Redirect Plugin
  * Copyright (C) 2004-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
  * This program is licensed under GPL. See COPYING for details
  *
  */


/**
  * Register this plugin with SquirrelMail 
  *
  */
function squirrelmail_plugin_init_login_redirect() 
{

   global $squirrelmail_plugin_hooks;

   $squirrelmail_plugin_hooks['login_cookie']['login_redirect'] = 'redirect_login';

}



/** @ignore */
if (!defined('SM_PATH'))
   define('SM_PATH', '../');



/**
  * Returns version info about this plugin
  *
  */
function login_redirect_version() 
{

    return '1.1-1.2.0';

}



/**
  * Pushes user to different login page (custom portal, etc)
  *
  */
function redirect_login() 
{

   include_once(SM_PATH . 'plugins/login_redirect/functions.php');
   redirect_login_do();

}



?>
